import h5py
from scipy.stats import qmc


def generate_lhs_unit_cube(
    n_parameters: int, n_samples: int, file_name: str
) -> None:
    """
    generate a until latin hypercube for faster generation
    of points to be scaled later

    :param n_parameters:
    :type n_parameters: int
    :param n_samples:
    :type n_samples: int
    :param file_name:
    :type file_name: str
    :returns:

    """


    sampling = qmc.LatinHypercube(d=n_parameters, optimization="random-cd")

    samples = sampling.random(n_samples)

    with h5py.File(file_name, "w") as f:

        f.create_dataset("lhs_points", data=samples, compression="gzip")



from ronswanson.band_simulation import BandSimulation as Simulation
from joblib import Parallel, delayed
import json
import numpy as np
from tqdm.auto import tqdm
from ronswanson import ParameterGrid
from ronswanson.utils.logging import setup_logger
from ronswanson.simulation import gather
log = setup_logger(__name__)

pg = ParameterGrid.from_yaml('/Users/jburgess/coding/projects/ronswanson/scripts/parameters.yml')
def func(i):
    params = pg.at_index(i)
    simulation = Simulation(i, params, pg.energy_grid,'/Users/jburgess/coding/projects/ronswanson/scripts/test_database.h5')
    simulation.run()
iteration = [i for i in range(0, pg.n_points)]
Parallel(n_jobs=10)(delayed(func)(i) for i in tqdm(iteration, colour='#FC0A5A'))
gather('/Users/jburgess/coding/projects/ronswanson/scripts/test_database.h5', 0, clean=True)



import click

from ronswanson.utils.check_complete import (
    examine_parameter,
    examine_parameter_detailed,
)


@click.command()
@click.argument('database', nargs=1)
@click.argument('parameter_grid', nargs=1)
@click.argument('parameter', nargs=1)
def examine_simulation(
    database: str, parameter_grid: str, parameter: str
) -> None:

    examine_parameter(database, parameter_grid, parameter)


@click.command()
@click.argument('database', nargs=1)
@click.argument('parameter_grid', nargs=1)
@click.argument('parameter', nargs=1)
@click.option('--colormap', default=None)
def examine_simulation_detailed(
        database: str, parameter_grid: str, parameter: str, colormap
) -> None:

    examine_parameter_detailed(database, parameter_grid, parameter, colormap)



from pathlib import Path
import yaml
from ronswanson.utils.package_data import get_path_of_data_file

test_params = str(get_path_of_data_file("test_params.yml"))

out = {}

out[
    "import_line"
] = "from ronswanson.band_simulation import BandSimulation as Simulation"
out["parameter_grid"] = str(get_path_of_data_file("test_params.yml"))
out["out_file"] = "database_para.h5"

simulation = {}
simulation["n_mp_jobs"] = 8

out["simulation"] = simulation

file_name = str(Path("sim_build.yml").absolute())

with Path(file_name).open("w") as f:

    yaml.dump(out, stream=f, Dumper=yaml.SafeDumper)
